==> Morpho-0.2.tar.gz: Morpho-0.2/src/jp/morpho/webapp/servlet/jsp/tagext/html/CoreAttrs.java <==
/*
 * Copyright (c) 2003, Morpho Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the Morpho Project nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.morpho.webapp.servlet.jsp.tagext.html;

/**
 * <P>
 * Generic Attributes  coreattrs ɽޤ
 * </P>
 * <P>
 * coreattrs  HTML 4 ϼΤȤǤ
 * <PRE>
 * &lt;!ENTITY % coreattrs
 *  "id          ID             #IMPLIED  -- document-wide unique id --
 *   class       CDATA          #IMPLIED  -- space-separated list of classes --
 *   style       %StyleSheet;   #IMPLIED  -- associated style info --
 *   title       %Text;         #IMPLIED  -- advisory title --"
 *   &gt;
 * </PRE>
 * </P>
 * @author Kumiko Hiroi
 */
public interface CoreAttrs
{
	/**
	 * <P>
	 * class °֤ޤ
	 * </P>
	 * @return class °
	 */
	public String getStyleClass();

	/**
	 * <P>
	 * id °֤ޤ
	 * </P>
	 * @return id °
	 */
	public String getStyleId();

	/**
	 * <P>
	 * style °֤ޤ
	 * </P>
	 * @return style °
	 */
	public String getStyle();

	/**
	 * <P>
	 * title °֤ޤ
	 * </P>
	 * @return title °
	 */
	public String getTitle();

	/**
	 * <P>
	 * class °ꤷޤ
	 * </P>
	 * @param cls class °
	 */
	public void setStyleClass(String cls);

	/**
	 * <P>
	 * id °ꤷޤ
	 * </P>
	 * @param id id °
	 */
	public void setStyleId(String id);

	/**
	 * <P>
	 * style °ꤷޤ
	 * </P>
	 * @param style style °
	 */
	public void setStyle(String style);

	/**
	 * <P>
	 * title °ꤷޤ
	 * </P>
	 * @param title title °
	 */
	public void setTitle(String title);

}

==> Morpho-1.0.tar.gz: Morpho-1.0/src/jp/morpho/webapp/servlet/jsp/tagext/html/CoreAttrs.java <==
/*
 * Copyright (c) 2003, Morpho Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the Morpho Project nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.morpho.webapp.servlet.jsp.tagext.html;

/**
 * <P>
 * Generic Attributes  coreattrs \܂B
 * </P>
 * <P>
 * coreattrs  HTML 4 `͎̂ƂłB
 * <PRE>
 * &lt;!ENTITY % coreattrs
 *  "id          ID             #IMPLIED  -- document-wide unique id --
 *   class       CDATA          #IMPLIED  -- space-separated list of classes --
 *   style       %StyleSheet;   #IMPLIED  -- associated style info --
 *   title       %Text;         #IMPLIED  -- advisory title --"
 *   &gt;
 * </PRE>
 * </P>
 * @author Kumiko Hiroi
 */
public interface CoreAttrs
{
	/**
	 * <P>
	 * class Ԃ܂B
	 * </P>
	 * @return class 
	 */
	public String getStyleclass();

	/**
	 * <P>
	 * id Ԃ܂B
	 * </P>
	 * @return id 
	 */
	public String getStyleid();

	/**
	 * <P>
	 * style Ԃ܂B
	 * </P>
	 * @return style 
	 */
	public String getStyle();

	/**
	 * <P>
	 * title Ԃ܂B
	 * </P>
	 * @return title 
	 */
	public String getTitle();

	/**
	 * <P>
	 * class ݒ肵܂B
	 * </P>
	 * @param cls class 
	 */
	public void setStyleclass(String cls);

	/**
	 * <P>
	 * id ݒ肵܂B
	 * </P>
	 * @param id id 
	 */
	public void setStyleid(String id);

	/**
	 * <P>
	 * style ݒ肵܂B
	 * </P>
	 * @param style style 
	 */
	public void setStyle(String style);

	/**
	 * <P>
	 * title ݒ肵܂B
	 * </P>
	 * @param title title 
	 */
	public void setTitle(String title);

}
